@@ -3,7 +3,7 @@ package App::BloomUtils;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-24'; # DATE
 our $DIST = 'App-BloomUtils'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -128,9 +128,9 @@ sub gen_bloom_filter {
         );
     }
     return $res unless $res->[0] == 200;
-    my $m = $res->[2]{actual_m};
-    my $k = $res->[2]{actual_k};
-    log_info "Will be creating bloom filter with num_bits (m)=%d, num_hashes (k)=%d, actual false-positive rate=%.5f%% (when num_items=%d), bloom filter size=%d bytes",
+    my $m = $args{num_bits} // $res->[2]{actual_m};
+    my $k = $args{num_hashes} // $res->[2]{actual_k};
+    log_info "Will be creating bloom filter with num_bits (m)=%d, num_hashes (k)=%d, actual false-positive rate=%.5f%% (when num_items=%d), actual bloom filter size=%d bytes",
         $m, $k, $res->[2]{actual_p}*100, $res->[2]{n}, $res->[2]{actual_bloom_size};
 
     my $bf = Algorithm::BloomFilter->new($m, $k);
@@ -300,7 +300,7 @@ App::BloomUtils - Utilities related to bloom filters
 
 =head1 VERSION
 
-This document describes version 0.005 of App::BloomUtils (from Perl distribution App-BloomUtils), released on 2020-05-24.
+This document describes version 0.006 of App::BloomUtils (from Perl distribution App-BloomUtils), released on 2020-05-24.
 
 =head1 DESCRIPTION
 
